;| cmr:ShowPlotStylesToggle
-------------------------------------------------------------------------------

Schaltet die Anzeige der aktuell eingestellten Plotstiltabelle ein bzw. aus

(Der Schalter steht in AutoCAD nur in der Seiteneinrichtung zur Verfgung.)


-------------------------------------------------------------------------------
Copyright (C) 2012 Markus Hoffmann
www.CADmaro.de
-------------------------------------------------------------------------------
FREEWARE:
Dieser Quellcode darf unbegrenzt und fr jeden Zweck verwendet werden sofern
keine Gebhr erhoben wird. Der Quellcode darf weiterhin nach eigenen
Bedrfnissen anpasst, verbessert, kopiert und weitergegeben werden. Der
Urheberrechtshinweis darf nicht entfernt werden.
-------------------------------------------------------------------------------
|;
(defun c:cmr:ShowPlotStylesToggle (/ symShowPStyles strPStyle lstPStylesAvail cannot)
  (mx:Init)
  (setq symShowPStyles (vlax-get-property objAcLayout 'ShowPlotstyles))
  (setq strPStyle (vlax-get-property objAcLayout 'StyleSheet)) ; aktuelle Plotstiltabelle
  (setq lstPStylesAvail (cmr:AvailablePlotstyles)) ; listet alle erreichbaren Plotstiltabellen
  (if (and
        (< (atof (getvar "acadver")) 18.2)
        (not (member (getvar "CTAB") (layoutlist)))
      )
    (setq cannot 'T)
  )                                     ; vor Version 2012 knnen keine Plotstile im Modell angezeigt werden
  (cond
    ((and
       (member strPStyle lstPStylesAvail)
       (= :vlax-false symShowPStyles)
     )
     (if cannot
       (princ "\nIn dieser Version knnen keine Plotstile im Modellbereich angezeigt werden.")
       (progn
         (cmr:ShowPlotStylesToggle 1)
         (princ (strcat "\nPlotstiltabelle " strPStyle " wird angezeigt."))
       )
     )
    )
    ((= :vlax-true symShowPStyles)
     (if cannot
       (princ "\nIn dieser Version knnen keine Plotstile im Modellbereich angezeigt werden.")
       (progn
         (cmr:ShowPlotStylesToggle 0)
         (princ "\nAnzeige von Plotstilen ist deaktiviert.")
       )
     )
    )
    ('T
     (if cannot
       (princ "\nIn dieser Version knnen keine Plotstile im Modellbereich angezeigt werden.")
       (alert "Die aktuell eingestellte Plotstiltabelle kann nicht angezeigt werden!")
     )
    )
  )
  (mx:Reset)
  (princ)
)

(defun cmr:ShowPlotStylesToggle (mode)
  (mx:Init)
  (vlax-put-property
    objAcLayout
    'ShowPlotstyles
    (if (= 1 mode)
      :vlax-true
      :vlax-false
    )
  )
  (vlax-invoke-method objAcDoc 'Regen acAllViewports)
)

(defun cmr:AvailablePlotstyles ()
  (vlax-safearray->list
    (vlax-variant-value
      (vlax-invoke-method
        objAcLayout
        'GetPlotStyleTableNames
      )
    )
  )
)

 ;| mx:Init

Initialisierung
|;
(defun mx:Init ()
  (vl-load-com)
  (setq objAcDoc
         (vlax-get-property
           (vlax-get-acad-object)
           'ActiveDocument
         )
  )
  (setq objAcLayout (vlax-get-property objAcDoc 'ActiveLayout))
  (setq intECHO (getvar "CMDECHO"))
  (setvar "CMDECHO" 0)
  (setq errorMX *error*
        *error* mx:Error
  )
  (vlax-invoke-method objAcDoc 'EndUndomark)
  (vlax-invoke-method objAcDoc 'StartUndomark)
)

 ;| mx:Reset

Zurcksetzen
|;
(defun mx:Reset ()
  (setvar "CMDECHO" intECHO)
  (vlax-invoke-method objAcDoc 'EndUndomark)
  (mapcar
    'vlax-release-object
    (list objAcDoc objAcLayout)
  )
  (setq *error* errorMX)
  (mapcar
    '(lambda (arg)
       (set
         arg
         'nil
       )
     )
    (list 'errorMX 'intECHO 'objAcDoc 'objAcLayout)
  )
)

 ;| mx:Error

Errorfunktion
|;
(defun mx:Error (s)
  (print (strcat "Fehler " s))
  (command)
  (command "_.undo" "_back")
  (mx:Reset)
  (princ)
)

(defun c:SPT () (c:cmr:ShowPlotStylesToggle))

(princ
  "cmr:ShowPlotStylesToggle.lsp wurde geladen. Start mit dem Befehl \"SPT\". www.CADmaro.de"
)
(princ)